@@ -156,7 +156,7 @@ shinyServer(function(input, output, session) {
       regex <- list()
       for (i in 1:length(seq)){
         if (input$motif_sel == "RxLR"){
-          regex[[i]] <- unlist(gregexpr(seq[[i]], pattern="^\\w{12,60}r\\wlr\\w{6,10}eer", perl = T,ignore.case = T))
+          regex[[i]] <- unlist(gregexpr(seq[[i]], pattern="^\\w{10,40}\\w{1,96}R\\wLR\\w{1,40}eer", perl = T,ignore.case = T))
         } else if (input$motif_sel == "CRN"){
           regex[[i]] <- unlist(gregexpr(seq[[i]], pattern="^\\w{1,90}LFLAK\\w+", perl = T,ignore.case = T))
         }
@@ -230,11 +230,13 @@ shinyServer(function(input, output, session) {
           stock.name <- gsub(mafft.out.name, pattern = ".fasta", replacement = ".stockholm"
           )
           hmmbuild_command <- c(get_hmmer_path("hmmbuild.exe", hmm.path),
+                                "--seed", input$seed,
                                 "--amino",
                                 hmmbuild.out,
                                 stock.name)
         } else {
           hmmbuild_command <- c(get_hmmer_path("hmmbuild", hmm.path),
+                                "--seed",input$seed,
                                 "--amino",
                                 hmmbuild.out,
                                 mafft.out.name)
@@ -243,9 +245,11 @@ shinyServer(function(input, output, session) {
         Sys.sleep(0.2)
         if (Sys.info()[['sysname']] %in% "Windows"){
           hmmpress_command <- c(get_hmmer_path("hmmpress.exe", hmm.path),
+                                "-f",
                                 hmmbuild.out)
         } else {
           hmmpress_command <- c(get_hmmer_path("hmmpress", hmm.path),
+                                "-f",
                                 hmmbuild.out)
         }
       system2(hmmpress_command)
@@ -265,12 +269,14 @@ shinyServer(function(input, output, session) {
         if (Sys.info()[['sysname']] %in% "Windows"){
           hmmsearch_command <- c(get_hmmer_path("hmmsearch.exe", hmm.path),
                                  "-T", "0",
+                                 "--seed", input$seed,
                                  "--tblout", hmmsearch.out,
                                  hmmbuild.out,
                                  original.seq)
         } else {
           hmmsearch_command <- c(get_hmmer_path("hmmsearch", hmm.path),
                                  "-T", "0",
+                                 "--seed", input$seed,
                                  "--tblout", hmmsearch.out,
                                  hmmbuild.out,
                                  original.seq)
